import sys
import requests

def main(filename: str):
    validnames = {
        'wp-login.php',
        '.env',
        'plugins/system/debug/debug.xml',
        'administrator/language/en-GB/en-GB.xml',
        'administrator/help/en-GB/toc.json',
        '.git/config',
        'vendor/phpunit/phpunit/src/Util/PHP/eval-stdin.php',
        'xmlrpc.php',
        'wp1/wp-includes/wlwmanifest.xml',
        'wp/wp-includes/wlwmanifest.xml',
        'wordpress/wp-includes/wlwmanifest.xml',
        'web/wp-includes/wlwmanifest.xml',
        'test/wp-includes/wlwmanifest.xml',
        'site/wp-includes/wlwmanifest.xml',
        'shop/wp-includes/wlwmanifest.xml',
        'cms/wp-includes/wlwmanifest.xml',
        'blog/wp-includes/wlwmanifest.xml',
        '2019/wp-includes/wlwmanifest.xml',
        'wp-load.php',
        'public/_ignition/health-check',
        '_ignition/health-check',
        'admin/.env',
        'protected/.env',
        'wp-includes/wp-class.php',
        'wp-commentin.php',
        'wp-signin.php'
    }
    hitfiles = {}.fromkeys(validnames, 0)
    requesters = {}
    ips = {}
    for ip, date, time, timezone, status, method, file in filterwords(filename, validnames):
        hitfiles[file] += 1

        if ip in requesters:
            requesters[ip] += 1
        else:
            requesters[ip] = 1
            latlon = get_ip_latlon(ip)
            if latlon is not None:
                ips[ip] = latlon

    print(f'{hitfiles = }')
    print(f'{requesters = }')
    print(f'{ips = }')
    req_list = list(requesters)
    req_list.sort(key=req_list.count)
    print(f'{req_list = }')

def get_ip_latlon(ip: str) -> (int, int):
    # make a reqest to ip-api.com to associate an ip to a
    # latitude and longitude
    addr = f'http://ip-api.com/json/{ip}'
    response = requests.get(addr)
    resulting_dict = eval(response.content)
    if resulting_dict['status'] != 'fail':
        return resulting_dict['lat'], resulting_dict['lon']

def filterwords(filename: str, validnames: set):
    with open(filename, 'r') as f:
        for line in f:
            # IP,YYMMDD hhmmss TIMEZONE,STATUS,METHOD,FILE
            ip, timethings, status, method, filepath = line.split(',', 4)
            file = '/'.join(filepath.split('/')[4:]).strip()
            if (
                status != '200'
                or method != 'GET'
                or file not in validnames
            ): continue
            date, time, timezone = timethings.split(' ')
            yield ip, date, time, timezone, status, method, file

if __name__ == '__main__':
    main(sys.argv[1])